@@ -14,7 +14,7 @@ package MCE::Core::Input::Sequence;
 use strict;
 use warnings;
 
-our $VERSION = '1.884';
+our $VERSION = '1.887';
 
 ## Items below are folded into MCE.
 
@@ -56,7 +56,8 @@ sub _worker_sequence_queue {
    # inlined for performance
    $_DAT_LOCK = $self->{'_mutex_'.( $self->{_wid} % 2 + 10 )};
    $_dat_ex = sub {
-      MCE::Util::_sock_ready($_DAT_LOCK->{_r_sock}) if $_is_MSWin32;
+      CORE::lock($_DAT_LOCK->{_t_lock}), MCE::Util::_sock_ready($_DAT_LOCK->{_r_sock})
+         if $_is_MSWin32;
       MCE::Util::_sysread($_DAT_LOCK->{_r_sock}, my($b), 1), $_DAT_LOCK->{ $_pid } = 1
          unless $_DAT_LOCK->{ $_pid };
    };
@@ -228,7 +229,7 @@ MCE::Core::Input::Sequence - Sequence of numbers (for task_id == 0)
 
 =head1 VERSION
 
-This document describes MCE::Core::Input::Sequence version 1.884
+This document describes MCE::Core::Input::Sequence version 1.887
 
 =head1 DESCRIPTION
 
